@@ -12,18 +12,13 @@ on_failure(is_input_id) <- function(call, env) {
 
 
 is_header <- function(x) {
-  is.null(x) || (is.character(x) && length(x) == 1 && !is.na(x))
+  is.null(x) || (length(x) == 1 && (is.na(x) || is.character(x)))
 }
 
 on_failure(is_header) <- function(call, env) {
-  paste0(deparse(call$x), " is not a string (length 1 character)")
+  paste0(deparse(call$x), " must be NULL or a string with at least 1 character")
 }
 
 
 # -------------------------------------------------------------------------
 
-
-
-on_failure(is_header) <- function(call, env) {
-  paste0(deparse(call$x), " must be produced by `sortable_options()`")
-}
