@@ -52,7 +52,8 @@ is_add_rank_list <- function(x) {
 #'   be used to define custom styling.
 #'
 #' @param group_name Passed to `SortableJS` as the group name. Also the input
-#'   value set in Shiny. (`input[[group_name]]`)
+#'   value set in Shiny. (`input[[group_name]]`). Items can be dragged between
+#'   bucket lists which share the same group name.
 #'
 #' @param group_put_max Not yet implemented
 #'
@@ -73,7 +74,7 @@ is_add_rank_list <- function(x) {
 #' ## Example of a shiny app
 #' if (interactive()) {
 #'   app <- system.file(
-#'     "shiny-examples/bucket_list/app.R",
+#'     "shiny/bucket_list/app.R",
 #'     package = "sortable"
 #'   )
 #'   shiny::runApp(app)
@@ -102,7 +103,7 @@ bucket_list <- function(
   class <- paste(class, collapse = " ")
 
   # capture the dots
-  ellipsis::check_dots_unnamed()
+  rlang::check_dots_unnamed()
   dot_vals <- rlang::list2(...)
 
   # Remove any NULL elements
@@ -151,7 +152,7 @@ bucket_list <- function(
   z <- tagList(
     tags$div(
       class = paste("bucket-list-container", class),
-      id = paste0("bucket-list-", css_id),
+      id = as_bucket_list_id(css_id),
       title_tag,
       tags$div(
         class = paste(class, "bucket-list",
