@@ -2,7 +2,7 @@
 
 if (interactive()) {
   rank_list(
-    text = "You can drag, drap and re-order these items:",
+    text = "You can drag, drop and re-order these items:",
     labels = c("one", "two", "three", "four", "five"),
     input_id = "example_2"
   )
